<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Engadir complementos</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="102"/>
        <source>Add Widget</source>
        <translation>Engadir trebello</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="112"/>
        <source>Close</source>
        <translation>Pechar</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(só se permite unha instancia de vez)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Configurar o panel</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="39"/>
        <source>Placement</source>
        <translation>Colocación</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="43"/>
        <source>Styling</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="47"/>
        <source>Widgets</source>
        <translation>Trebellos</translation>
    </message>
</context>
<context>
    <name>ConfigPlacement</name>
    <message>
        <location filename="../config/configplacement.ui" line="20"/>
        <source>Configure Placement</source>
        <translation>Configurar a colocación</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="44"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Un valor negativo de píxeles estabelece a lonxitude do panel nesa mesma cantidade menos de píxeles que o espazo dispoñíbel de pantalla.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;P. ex. «Lonxitude» estabelecida a -100px, o tamaño da pantalla é de 1000px, entón a lonxitude real do panel será de 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="81"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="88"/>
        <source>Length:</source>
        <translation>Lonxitude:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="109"/>
        <location filename="../config/configplacement.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Tamaño da icona:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="173"/>
        <source>Rows:</source>
        <translation>Filas:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Aliñamento &amp;e posición</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Aliñamento:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="219"/>
        <location filename="../config/configplacement.cpp" line="188"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="224"/>
        <location filename="../config/configplacement.cpp" line="189"/>
        <location filename="../config/configplacement.cpp" line="195"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="229"/>
        <location filename="../config/configplacement.cpp" line="190"/>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="237"/>
        <source>Position:</source>
        <translation>Posición:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>Agochar a&amp;utomaticamente</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="262"/>
        <location filename="../config/configplacement.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Cero equivale a non usar animacións</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Duración da animación:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="288"/>
        <location filename="../config/configplacement.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="301"/>
        <location filename="../config/configplacement.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Cero equivale a sen atraso</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Amosar cun atraso de:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>Marxe fina visible para o panel agochado</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="334"/>
        <source>Hide only on overlapping a window</source>
        <translation>Ocultar só ao solapar unha xanela</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="344"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Non permitir que as xanelas maximizadas queden baixo a xanela do panel</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="347"/>
        <source>Reserve space on display</source>
        <translation>Reservar espazo na pantalla</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="154"/>
        <source>Top of desktop</source>
        <translation>Bordo superior do escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="155"/>
        <source>Left of desktop</source>
        <translation>Bordo esquerdo do escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="156"/>
        <source>Right of desktop</source>
        <translation>Bordo dereito do escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="157"/>
        <source>Bottom of desktop</source>
        <translation>Bordo inferior do escritorio</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="166"/>
        <source>Top of desktop %1</source>
        <translation>Bordo superior do escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="167"/>
        <source>Left of desktop %1</source>
        <translation>Bordo esquerdo do escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="168"/>
        <source>Right of desktop %1</source>
        <translation>Bordo dereito do escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="169"/>
        <source>Bottom of desktop %1</source>
        <translation>Bordo inferior do escritorio %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="194"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="196"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Configurar os complementos</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Nota: Os cambios feitos nesta páxina non é posíbel desfacelos.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Mover cara a arriba</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Mover cara a abaixo</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Engadir</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Retirar</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
</context>
<context>
    <name>ConfigStyling</name>
    <message>
        <location filename="../config/configstyling.ui" line="20"/>
        <source>Configure Styling</source>
        <translation>Configurar o estilo</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="44"/>
        <source>Custom styling</source>
        <translation>Estilo personalizado</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="65"/>
        <source>Font color:</source>
        <translation>Cor da letra:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="105"/>
        <source>Background color:</source>
        <translation>Cor do fondo:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="144"/>
        <source>Background opacity:</source>
        <translation>Opacidade do fondo:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="176"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;É necesaria a composición para ter transparencia no panel.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="204"/>
        <source>Background image:</source>
        <translation>Imaxe de fondo:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="256"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>Unha solución parcial para estilos de compoñentes
que non poden dar un tema separado ao panel.

É posíbel que tamén queira desactivar:

Configuración de aparencia de LXQt →
Tema de icona →
Colorar as iconas segundo o estilo dos trebellos (paleta)</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="266"/>
        <source>Override icon &amp;theme</source>
        <translation>Substituír o &amp;tema de iconas</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="281"/>
        <source>Icon theme for panels:</source>
        <translation>Tema de iconas para os paneis:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="189"/>
        <location filename="../config/configstyling.cpp" line="205"/>
        <source>Pick color</source>
        <translation>Seleccione unha cor</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Pick image</source>
        <translation>Seleccione unha imaxe</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Images (*.png *.gif *.jpg *.svg)</source>
        <translation>Imaxes (*.png *.gif *.jpg *.svg)</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1361"/>
        <location filename="../lxqtpanel.cpp" line="1387"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1390"/>
        <source>Configure Panel</source>
        <translation>Configurar o panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1395"/>
        <source>Manage Widgets</source>
        <translation>Administrar os trebellos</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1401"/>
        <source>Add New Panel</source>
        <translation>Engadir un panel novo</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1408"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Retirar o panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1413"/>
        <source>Lock This Panel</source>
        <translation>Bloquear este panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1576"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Retirar o panel</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1577"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>A retirada dun panel non pode desfacerse.
Confirma que quere retirar o panel?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="445"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Configurar «%1»</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="450"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Desprazar «%1»</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="458"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Retirar «%1»</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="340"/>
        <source>Use alternate configuration file.</source>
        <translation>Usar un ficheiro alternativo de configuración.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="341"/>
        <source>Configuration file</source>
        <translation>Ficheiro de configuración</translation>
    </message>
</context>
</TS>
